Crate chessie_types

Chessie Types

Contains primitives types for the chessie crate.

All types are re-exported by chessie, so you shouldn’t need to use this crate directly for any reason.

However, if you’d like to use this in your own projects, you can find the source code here.

Modules

prelude
Re-exports all the things you’ll need.

Structs

Bitboard
A Bitboard represents the game board as a set of bits. They are used for various computations, such as fetching valid moves or computing move costs.
BitboardIter
An iterator over all set bits in a Bitboard.
BitboardSubsetIter
An iterator over all possible subsets of a Bitboard.
File
Represents one of eight ranks on a chess board.
Piece
Represents a chess piece on the game board.
Rank
Represents one of eight ranks on a chess board.
Square
Represents a single square on an 8x8 chess board.
XoShiRo
A pseudo-random number generator using the “xoshiro” algorithm.

Enums

Color
Represents the color of a player, piece, square, etc. within a chess board.
PieceKind
Represents the kind (or “role”) that a chess piece can be.

Constants

BISHOP_DELTAS
Deltas for the movement of the Bishop.
FEN_KIWIPETE
A popular FEN string for debugging move generation.
FEN_STARTPOS
FEN string for the starting position of chess.
KNIGHT_DELTAS
Deltas for the movement of the Knight.
MAX_NUM_MOVES
Maximum possible number of moves in a given chess position.
NUM_CASTLING_RIGHTS
Number of possible combinations of castling rights.
QUEEN_DELTAS
Deltas for the movement of the Queen.
ROOK_DELTAS
Deltas for the movement of the Rook.

Functions

generate_magics
Generate magics for the Bishop and Rook and store them in <outdir>/rook_magics.rs and <outdir>/bishop_magics.rs.
generate_piece_attack_datfiles
Generates the default mobility for each of the pieces of standard chess, and writes the mobility to new files created in outdir.
generate_ray_table_datfiles
Generates .dat files for ray tables.