Modules
- prelude
- Re-exports all the things you’ll need.
Structs
- Bitboard
- A
Bitboardrepresents the game board as a set of bits. They are used for various computations, such as fetching valid moves or computing move costs. - Bitboard
Iter - An iterator over all set bits in a
Bitboard. - Bitboard
Subset Iter - An iterator over all possible subsets of a
Bitboard. - File
- Represents one of eight ranks on a chess board.
- Piece
- Represents a chess piece on the game board.
- Rank
- Represents one of eight ranks on a chess board.
- Square
- Represents a single square on an
8x8chess board. - XoShiRo
- A pseudo-random number generator using the “xoshiro” algorithm.
Enums
- Color
- Represents the color of a player, piece, square, etc. within a chess board.
- Piece
Kind - Represents the kind (or “role”) that a chess piece can be.
Constants
- BISHOP_
DELTAS - Deltas for the movement of the Bishop.
- FEN_
KIWIPETE - A popular FEN string for debugging move generation.
- FEN_
STARTPOS - FEN string for the starting position of chess.
- KNIGHT_
DELTAS - Deltas for the movement of the Knight.
- MAX_
NUM_ MOVES - Maximum possible number of moves in a given chess position.
- NUM_
CASTLING_ RIGHTS - Number of possible combinations of castling rights.
- QUEEN_
DELTAS - Deltas for the movement of the Queen.
- ROOK_
DELTAS - Deltas for the movement of the Rook.
Functions
- generate_
magics - Generate magics for the Bishop and Rook and store them in
<outdir>/rook_magics.rsand<outdir>/bishop_magics.rs. - generate_
piece_ attack_ datfiles - Generates the default mobility for each of the pieces of standard chess, and writes the mobility to new files created in
outdir. - generate_
ray_ table_ datfiles - Generates
.datfiles for ray tables.